#pragma once

#include "CoreMinimal.h"
#include "WingBasics.h"
#include "WingManual.h"
#include "WingServer.h"
#include "Documentation_Manual.generated.h"

UCLASS()
class UWing_Documentation_Manual : public UWingHandler
{
	GENERATED_BODY()

public:

	virtual void Register() override
	{
		UWingServer::AddHandler(this, TEXT("Print the entire manual."));
	}
	virtual void Handle() override
	{
		UWingManualSections::FetcherPaths();
		UWingManualSections::ExpressingTypes();
		UWingManualSections::VariableDeclarations();
		UWingManualSections::EscapeSequencesInFNames();
		UWingManualSections::MaterialEditing();
		UWingManualSections::NodeContextMenus();
		UWingManualSections::VariableGettersAndSetters();
		UWingManualSections::BestPerformance();
		UWingManualSections::ImportantCommands();
	}
};
